/*******************************************************************************
* File Name: .h
* Version 1.10
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component in I2C mode.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_UART_G_H)
#define CY_SCB_PVT_UART_G_H

#include "UART_G.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define UART_G_SetI2CExtClkInterruptMode(interruptMask) UART_G_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define UART_G_ClearI2CExtClkInterruptSource(interruptMask) UART_G_CLEAR_INTR_I2C_EC(interruptMask)
#define UART_G_GetI2CExtClkInterruptSource()                (UART_G_INTR_I2C_EC_REG)
#define UART_G_GetI2CExtClkInterruptMode()                  (UART_G_INTR_I2C_EC_MASK_REG)
#define UART_G_GetI2CExtClkInterruptSourceMasked()          (UART_G_INTR_I2C_EC_MASKED_REG)

/* APIs to service INTR_SPI_EC register */
#define UART_G_SetSpiExtClkInterruptMode(interruptMask) UART_G_WRITE_INTR_SPI_EC_MASK(interruptMask)
#define UART_G_ClearSpiExtClkInterruptSource(interruptMask) UART_G_CLEAR_INTR_SPI_EC(interruptMask)
#define UART_G_GetExtSpiClkInterruptSource()                 (UART_G_INTR_SPI_EC_REG)
#define UART_G_GetExtSpiClkInterruptMode()                   (UART_G_INTR_SPI_EC_MASK_REG)
#define UART_G_GetExtSpiClkInterruptSourceMasked()           (UART_G_INTR_SPI_EC_MASKED_REG)

#if(UART_G_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void UART_G_SetPins(uint32 mode, uint32 subMode, uint32 uartTxRx);
#endif /* (UART_G_SCB_MODE_UNCONFIG_CONST_CFG) */

void UART_G_DisableTxPinsInputBuffer(void);
void UART_G_EnableTxPinsInputBuffer(void);


/**********************************
*     Vars with External Linkage
**********************************/

extern cyisraddress UART_G_customIntrHandler;
extern UART_G_BACKUP_STRUCT UART_G_backup;

#if(UART_G_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common config vars */
    extern uint8 UART_G_scbMode;
    extern uint8 UART_G_scbEnableWake;
    extern uint8 UART_G_scbEnableIntr;

    /* I2C config vars */
    extern uint8 UART_G_mode;
    extern uint8 UART_G_acceptAddr;

    /* SPI/UART config vars */
    extern volatile uint8 * UART_G_rxBuffer;
    extern uint8   UART_G_rxDataBits;
    extern uint32  UART_G_rxBufferSize;

    extern volatile uint8 * UART_G_txBuffer;
    extern uint8   UART_G_txDataBits;
    extern uint32  UART_G_txBufferSize;

    /* EZI2C config vars */
    extern uint8 UART_G_numberOfAddr;
    extern uint8 UART_G_subAddrSize;
#endif /* (UART_G_SCB_MODE_UNCONFIG_CONST_CFG) */

#endif /* (CY_SCB_PVT_UART_G_H) */


/* [] END OF FILE */
