/*******************************************************************************
* File Name: UART_G_SPI_UART.h
* Version 1.10
*
* Description:
*  This file provides constants and parameter values for the SCB Component in
*  SPI and UART modes.
*
* Note:
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_UART_G_H)
#define CY_SCB_SPI_UART_UART_G_H

#include "UART_G.h"


/***************************************
*   SPI Initial Parameter Constants
****************************************/

#define UART_G_SPI_MODE                   (0u)
#define UART_G_SPI_SUB_MODE               (0u)
#define UART_G_SPI_CLOCK_MODE             (0u)
#define UART_G_SPI_OVS_FACTOR             (16u)
#define UART_G_SPI_MEDIAN_FILTER_ENABLE   (0u)
#define UART_G_SPI_LATE_MISO_SAMPLE_ENABLE (0u)
#define UART_G_SPI_RX_DATA_BITS_NUM       (8u)
#define UART_G_SPI_TX_DATA_BITS_NUM       (8u)
#define UART_G_SPI_WAKE_ENABLE            (0u)
#define UART_G_SPI_BITS_ORDER             (1u)
#define UART_G_SPI_TRANSFER_SEPARATION    (1u)
#define UART_G_SPI_NUMBER_OF_SS_LINES     (1u)
#define UART_G_SPI_RX_BUFFER_SIZE         (8u)
#define UART_G_SPI_TX_BUFFER_SIZE         (8u)

#define UART_G_SPI_INTERRUPT_MODE         (0u)

#define UART_G_SPI_INTR_RX_MASK           (0u)
#define UART_G_SPI_INTR_TX_MASK           (0u)

#define UART_G_SPI_RX_TRIGGER_LEVEL       (7u)
#define UART_G_SPI_TX_TRIGGER_LEVEL       (0u)


/***************************************
*   UART Initial Parameter Constants
****************************************/

#define UART_G_UART_SUB_MODE              (0u)
#define UART_G_UART_DIRECTION             (3u)
#define UART_G_UART_DATA_BITS_NUM         (8u)
#define UART_G_UART_PARITY_TYPE           (2u)
#define UART_G_UART_STOP_BITS_NUM         (4u)
#define UART_G_UART_OVS_FACTOR            (12u)
#define UART_G_UART_IRDA_LOW_POWER        (0u)
#define UART_G_UART_MEDIAN_FILTER_ENABLE  (1u)
#define UART_G_UART_RETRY_ON_NACK         (0u)
#define UART_G_UART_IRDA_POLARITY         (0u)
#define UART_G_UART_DROP_ON_FRAME_ERR     (0u)
#define UART_G_UART_DROP_ON_PARITY_ERR    (0u)
#define UART_G_UART_WAKE_ENABLE           (0u)
#define UART_G_UART_RX_BUFFER_SIZE        (8u)
#define UART_G_UART_TX_BUFFER_SIZE        (8u)
#define UART_G_UART_MP_MODE_ENABLE        (0u)
#define UART_G_UART_MP_ACCEPT_ADDRESS     (0u)
#define UART_G_UART_MP_RX_ADDRESS         (2u)
#define UART_G_UART_MP_RX_ADDRESS_MASK    (255u)

#define UART_G_UART_INTERRUPT_MODE        (1u)

#define UART_G_UART_INTR_RX_MASK          (8u)
#define UART_G_UART_INTR_TX_MASK          (0u)

#define UART_G_UART_RX_TRIGGER_LEVEL      (4u)
#define UART_G_UART_TX_TRIGGER_LEVEL      (0u)

/* Sources of RX errors */
#define UART_G_INTR_RX_ERR        (UART_G_INTR_RX_OVERFLOW    | \
                                             UART_G_INTR_RX_UNDERFLOW   | \
                                             UART_G_INTR_RX_FRAME_ERROR | \
                                             UART_G_INTR_RX_PARITY_ERROR)

/* UART direction enum */
#define UART_G_UART_RX    (1u)
#define UART_G_UART_TX    (2u)
#define UART_G_UART_TX_RX (3u)


/***************************************
*   Conditional Compilation Parameters
****************************************/

#if(UART_G_SCB_MODE_UNCONFIG_CONST_CFG)

    /* Direction */
    #define UART_G_RX_DIRECTION           (1u)
    #define UART_G_TX_DIRECTION           (1u)
    #define UART_G_UART_RX_DIRECTION      (1u)
    #define UART_G_UART_TX_DIRECTION      (1u)

    /* Only external RX and TX buffer for uncofigured mode */
    #define UART_G_INTERNAL_RX_SW_BUFFER   (0u)
    #define UART_G_INTERNAL_TX_SW_BUFFER   (0u)

    /* Get RX and TX buffer size */
    #define UART_G_RX_BUFFER_SIZE (UART_G_rxBufferSize)
    #define UART_G_TX_BUFFER_SIZE (UART_G_txBufferSize)

    /* Return true if buffer is provided */
    #define UART_G_CHECK_RX_SW_BUFFER (NULL != UART_G_rxBuffer)
    #define UART_G_CHECK_TX_SW_BUFFER (NULL != UART_G_txBuffer)

    /* Alwasy provde global variables to support RX and TX buffers */
    #define UART_G_INTERNAL_RX_SW_BUFFER_CONST    (1u)
    #define UART_G_INTERNAL_TX_SW_BUFFER_CONST    (1u)

    /* Get wakeup enable option */
    #define UART_G_SPI_WAKE_ENABLE_CONST  (1u)
    #define UART_G_CHECK_SPI_WAKE_ENABLE  (0u != UART_G_scbEnableWake)
    #define UART_G_UART_WAKE_ENABLE_CONST (1u)

#else

    /* SPI internal RX and TX buffers */
    #define UART_G_INTERNAL_SPI_RX_SW_BUFFER  (UART_G_SPI_RX_BUFFER_SIZE > \
                                                                                            UART_G_FIFO_SIZE)
    #define UART_G_INTERNAL_SPI_TX_SW_BUFFER  (UART_G_SPI_TX_BUFFER_SIZE > \
                                                                                            UART_G_FIFO_SIZE)

    /* UART internal RX and TX buffers */
    #define UART_G_INTERNAL_UART_RX_SW_BUFFER  (UART_G_UART_RX_BUFFER_SIZE > \
                                                                                            UART_G_FIFO_SIZE)
    #define UART_G_INTERNAL_UART_TX_SW_BUFFER  (UART_G_UART_TX_BUFFER_SIZE > \
                                                                                            UART_G_FIFO_SIZE)

    /* SPI Direction */
    #define UART_G_SPI_RX_DIRECTION (1u)
    #define UART_G_SPI_TX_DIRECTION (1u)

    /* UART Direction */
    #define UART_G_UART_RX_DIRECTION (0u != (UART_G_UART_DIRECTION & UART_G_UART_RX))
    #define UART_G_UART_TX_DIRECTION (0u != (UART_G_UART_DIRECTION & UART_G_UART_TX))

    /* Direction */
    #define UART_G_RX_DIRECTION ((UART_G_SCB_MODE_SPI_CONST_CFG) ? \
                                            (UART_G_SPI_RX_DIRECTION) : (UART_G_UART_RX_DIRECTION))

    #define UART_G_TX_DIRECTION ((UART_G_SCB_MODE_SPI_CONST_CFG) ? \
                                            (UART_G_SPI_TX_DIRECTION) : (UART_G_UART_TX_DIRECTION))

    /* Internal RX and TX buffer: for SPI or UART */
    #if(UART_G_SCB_MODE_SPI_CONST_CFG)

        /* Internal SPI RX and TX buffer */
        #define UART_G_INTERNAL_RX_SW_BUFFER  (UART_G_INTERNAL_SPI_RX_SW_BUFFER)
        #define UART_G_INTERNAL_TX_SW_BUFFER  (UART_G_INTERNAL_SPI_TX_SW_BUFFER)

        /* Internal SPI RX and TX buffer size */
        #define UART_G_RX_BUFFER_SIZE         (UART_G_SPI_RX_BUFFER_SIZE + 1u)
        #define UART_G_TX_BUFFER_SIZE         (UART_G_SPI_TX_BUFFER_SIZE)
        
        /* Get wakeup enable option */
        #define UART_G_SPI_WAKE_ENABLE_CONST  (0u != UART_G_SPI_WAKE_ENABLE)
        #define UART_G_UART_WAKE_ENABLE_CONST (0u)

    #else

        /* Internal UART RX and TX buffer */
        #define UART_G_INTERNAL_RX_SW_BUFFER  (UART_G_INTERNAL_UART_RX_SW_BUFFER)
        #define UART_G_INTERNAL_TX_SW_BUFFER  (UART_G_INTERNAL_UART_TX_SW_BUFFER)

        /* Internal UART RX and TX buffer size */
        #define UART_G_RX_BUFFER_SIZE         (UART_G_UART_RX_BUFFER_SIZE + 1u)
        #define UART_G_TX_BUFFER_SIZE         (UART_G_UART_TX_BUFFER_SIZE)
        
        /* Get wakeup enable option */
        #define UART_G_SPI_WAKE_ENABLE_CONST  (0u)
        #define UART_G_UART_WAKE_ENABLE_CONST (0u != UART_G_UART_WAKE_ENABLE)
    #endif /* (UART_G_SCB_MODE_SPI_CONST_CFG) */

    /* Internal RX and TX buffer: for SPI or UART. Used in conditional compilation check */
    #define UART_G_CHECK_RX_SW_BUFFER (UART_G_INTERNAL_RX_SW_BUFFER)
    #define UART_G_CHECK_TX_SW_BUFFER (UART_G_INTERNAL_TX_SW_BUFFER)

    /* Provide global variables to support RX and TX buffers */
    #define UART_G_INTERNAL_RX_SW_BUFFER_CONST    (UART_G_INTERNAL_RX_SW_BUFFER)
    #define UART_G_INTERNAL_TX_SW_BUFFER_CONST    (UART_G_INTERNAL_TX_SW_BUFFER)
    
    /* Wakeup for SPI */
    #define UART_G_CHECK_SPI_WAKE_ENABLE  (UART_G_SPI_WAKE_ENABLE_CONST)

#endif /* End (UART_G_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Bootloader communication interface enable: NOT supported yet */
#define UART_G_SPI_BTLDR_COMM_ENABLED   ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UART_G) || \
                                                    (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

#define UART_G_UART_BTLDR_COMM_ENABLED   ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UART_G) || \
                                                    (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))


/***************************************
*       Type Definitions
***************************************/

/* UART_G_SPI_INIT_STRUCT */
typedef struct
{
    uint32 mode;
    uint32 submode;
    uint32 sclkMode;
    uint32 oversample;
    uint32 enableMedianFilter;
    uint32 enableLateSampling;
    uint32 enableWake;
    uint32 rxDataBits;
    uint32 txDataBits;
    uint32 bitOrder;
    uint32 transferSeperation;
    uint32 rxBufferSize;
    uint8* rxBuffer;
    uint32 txBufferSize;
    uint8* txBuffer;
    uint32 enableInterrupt;
    uint32 rxInterruptMask;
    uint32 rxTriggerLevel;
    uint32 txInterruptMask;
    uint32 txTriggerLevel;
} UART_G_SPI_INIT_STRUCT;

/* UART_G_UART_INIT_STRUCT */
typedef struct
{
    uint32 mode;
    uint32 direction;
    uint32 dataBits;
    uint32 parity;
    uint32 stopBits;
    uint32 oversample;
    uint32 enableIrdaLowPower;
    uint32 enableMedianFilter;
    uint32 enableRetryNack;
    uint32 enableInvertedRx;
    uint32 dropOnParityErr;
    uint32 dropOnFrameErr;
    uint32 enableWake;
    uint32 rxBufferSize;
    uint8* rxBuffer;
    uint32 txBufferSize;
    uint8* txBuffer;
    uint32 enableMultiproc;
    uint32 multiprocAcceptAddr;
    uint32 multiprocAddr;
    uint32 multiprocAddrMask;
    uint32 enableInterrupt;
    uint32 rxInterruptMask;
    uint32 rxTriggerLevel;
    uint32 txInterruptMask;
    uint32 txTriggerLevel;
} UART_G_UART_INIT_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

/* SPI specific functions */
#if(UART_G_SCB_MODE_UNCONFIG_CONST_CFG)
    void UART_G_SpiInit(const UART_G_SPI_INIT_STRUCT *config);
#endif /* (UART_G_SCB_MODE_UNCONFIG_CONST_CFG) */

#if(UART_G_SCB_MODE_SPI_INC)
    void UART_G_SpiSetActiveSlaveSelect(uint32 activeSelect);
#endif /* (UART_G_SCB_MODE_SPI_INC) */

/* UART specific functions */
#if(UART_G_SCB_MODE_UNCONFIG_CONST_CFG)
    void UART_G_UartInit(const UART_G_UART_INIT_STRUCT *config);
#endif /* (UART_G_SCB_MODE_UNCONFIG_CONST_CFG) */

#if(UART_G_SCB_MODE_UART_INC)
    void UART_G_UartSetRxAddress(uint32 address);
    void UART_G_UartSetRxAddressMask(uint32 addressMask);
#endif /* (UART_G_SCB_MODE_UART_INC) */

/* UART RX direction APIs */
#if(UART_G_UART_RX_DIRECTION)
    uint32 UART_G_UartGetChar(void);
    uint32 UART_G_UartGetByte(void);
#endif /* (UART_G_UART_RX_DIRECTION) */

/* UART TX direction APIs */
#if(UART_G_UART_TX_DIRECTION)
    #define UART_G_UartPutChar(ch)    UART_G_SpiUartWriteTxData((uint32)(ch))
    void UART_G_UartPutString(const char8 string[]);
    void UART_G_UartPutCRLF(uint32 txDataByte);
#endif /* (UART_G_UART_TX_DIRECTION) */

/* Common APIs Rx direction */
#if(UART_G_RX_DIRECTION)
    uint32 UART_G_SpiUartReadRxData(void);
    uint32 UART_G_SpiUartGetRxBufferSize(void);
    void   UART_G_SpiUartClearRxBuffer(void);
#endif /* (UART_G_RX_DIRECTION) */

/* Common APIs Tx direction */
#if(UART_G_TX_DIRECTION)
    void   UART_G_SpiUartWriteTxData(uint32 txDataByte);
    void   UART_G_SpiUartPutArray(const uint8 wrBuf[], uint32 count);
    void   UART_G_SpiUartClearTxBuffer(void);
    uint32 UART_G_SpiUartGetTxBufferSize(void);
#endif /* (UART_G_TX_DIRECTION) */

CY_ISR_PROTO(UART_G_SPI_UART_ISR);

#if(UART_G_UART_RX_WAKEUP_IRQ)
    CY_ISR_PROTO(UART_G_UART_WAKEUP_ISR);
#endif /* (UART_G_UART_RX_WAKEUP_IRQ) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (UART_G_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void UART_G_SpiCyBtldrCommStart(void);
    void UART_G_SpiCyBtldrCommStop (void);
    void UART_G_SpiCyBtldrCommReset(void);
    cystatus UART_G_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus UART_G_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (UART_G_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (UART_G_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void UART_G_UartCyBtldrCommStart(void);
    void UART_G_UartCyBtldrCommStop (void);
    void UART_G_UartCyBtldrCommReset(void);
    cystatus UART_G_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus UART_G_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (UART_G_UART_BTLDR_COMM_ENABLED) */


/***************************************
*     Buffer Access Macro Definitions
***************************************/

#if(UART_G_SCB_MODE_UNCONFIG_CONST_CFG)
    /* RX direction */
    void   UART_G_PutWordInRxBuffer  (uint32 idx, uint32 rxDataByte);
    uint32 UART_G_GetWordFromRxBuffer(uint32 idx);

    /* TX direction */
    void   UART_G_PutWordInTxBuffer  (uint32 idx, uint32 txDataByte);
    uint32 UART_G_GetWordFromTxBuffer(uint32 idx);

#else

    /* RX direction */
    #if(UART_G_INTERNAL_RX_SW_BUFFER_CONST)
        #define UART_G_PutWordInRxBuffer(idx, rxDataByte) \
                do{                                                 \
                    UART_G_rxBufferInternal[(idx)] = ((uint8) (rxDataByte)); \
                }while(0)

        #define UART_G_GetWordFromRxBuffer(idx) UART_G_rxBufferInternal[(idx)]

    #endif /* (UART_G_INTERNAL_RX_SW_BUFFER_CONST) */

    /* TX direction */
    #if(UART_G_INTERNAL_TX_SW_BUFFER_CONST)
        #define UART_G_PutWordInTxBuffer(idx, txDataByte) \
                    do{                                             \
                        UART_G_txBufferInternal[(idx)] = ((uint8) (txDataByte)); \
                    }while(0)

        #define UART_G_GetWordFromTxBuffer(idx) UART_G_txBufferInternal[(idx)]

    #endif /* (UART_G_INTERNAL_TX_SW_BUFFER_CONST) */

#endif /* (UART_G_TX_SW_BUFFER_ENABLE) */


/***************************************
*         SPI API Constants
***************************************/

/* SPI mode enum */
#define UART_G_SPI_SLAVE  (0u)
#define UART_G_SPI_MASTER (1u)

/* SPI sub mode enum */
#define UART_G_SPI_MODE_MOTOROLA      (0x00u)
#define UART_G_SPI_MODE_TI_COINCIDES  (0x01u)
#define UART_G_SPI_MODE_TI_PRECEDES   (0x11u)
#define UART_G_SPI_MODE_NATIONAL      (0x02u)
#define UART_G_SPI_MODE_MASK          (0x03u)
#define UART_G_SPI_MODE_TI_PRECEDES_MASK  (0x10u)

/* SPI phase and polarity mode enum */
#define UART_G_SPI_SCLK_CPHA0_CPOL0   (0x00u)
#define UART_G_SPI_SCLK_CPHA0_CPOL1   (0x02u)
#define UART_G_SPI_SCLK_CPHA1_CPOL0   (0x01u)
#define UART_G_SPI_SCLK_CPHA1_CPOL1   (0x03u)

/* SPI bits order enum */
#define UART_G_BITS_ORDER_LSB_FIRST   (0u)
#define UART_G_BITS_ORDER_MSB_FIRST   (1u)

/* SPI transfer separation enum */
#define UART_G_SPI_TRANSFER_SEPARATED     (0u)
#define UART_G_SPI_TRANSFER_CONTINUOUS    (1u)

/* "activeSS" constants for SpiSetActiveSlaveSelect() function */
#define UART_G_SPIM_ACTIVE_SS0    (0x00u)
#define UART_G_SPIM_ACTIVE_SS1    (0x01u)
#define UART_G_SPIM_ACTIVE_SS2    (0x02u)
#define UART_G_SPIM_ACTIVE_SS3    (0x03u)


/***************************************
*         UART API Constants
***************************************/

/* UART sub-modes enum */
#define UART_G_UART_MODE_STD          (0u)
#define UART_G_UART_MODE_SMARTCARD    (1u)
#define UART_G_UART_MODE_IRDA         (2u)

/* UART direction enum */
#define UART_G_UART_RX    (1u)
#define UART_G_UART_TX    (2u)
#define UART_G_UART_TX_RX (3u)

/* UART parity enum */
#define UART_G_UART_PARITY_EVEN   (0u)
#define UART_G_UART_PARITY_ODD    (1u)
#define UART_G_UART_PARITY_NONE   (2u)

/* UART stop bits enum */
#define UART_G_UART_STOP_BITS_1   (1u)
#define UART_G_UART_STOP_BITS_1_5 (2u)
#define UART_G_UART_STOP_BITS_2   (3u)

/* UART IrDA low power OVS enum */
#define UART_G_UART_IRDA_LP_OVS16     (16u)
#define UART_G_UART_IRDA_LP_OVS32     (32u)
#define UART_G_UART_IRDA_LP_OVS48     (48u)
#define UART_G_UART_IRDA_LP_OVS96     (96u)
#define UART_G_UART_IRDA_LP_OVS192    (192u)
#define UART_G_UART_IRDA_LP_OVS768    (768u)
#define UART_G_UART_IRDA_LP_OVS1536   (1536u)

/* Uart MP: mark (address) and space (data) bit definitions */
#define UART_G_UART_MP_MARK       (0x100u)
#define UART_G_UART_MP_SPACE      (0x000u)


/***************************************
*     Vars with External Linkage
***************************************/

#if(UART_G_SCB_MODE_UNCONFIG_CONST_CFG)
    extern const UART_G_SPI_INIT_STRUCT  UART_G_configSpi;
    extern const UART_G_UART_INIT_STRUCT UART_G_configUart;
#endif /* (UART_G_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*    Specific SPI Macro Definitions
***************************************/

#define UART_G_GET_SPI_INTR_SLAVE_MASK(sourceMask)  ((sourceMask) & UART_G_INTR_SLAVE_SPI_BUS_ERROR)
#define UART_G_GET_SPI_INTR_MASTER_MASK(sourceMask) ((sourceMask) & UART_G_INTR_MASTER_SPI_DONE)
#define UART_G_GET_SPI_INTR_RX_MASK(sourceMask) \
                                             ((sourceMask) & (uint32) ~UART_G_INTR_SLAVE_SPI_BUS_ERROR)

#define UART_G_GET_SPI_INTR_TX_MASK(sourceMask) \
                                             ((sourceMask) & (uint32) ~UART_G_INTR_MASTER_SPI_DONE)


/***************************************
*    Specific UART Macro Definitions
***************************************/

#define UART_G_UART_GET_CTRL_OVS_IRDA_LP(oversample) \
        ((UART_G_UART_IRDA_LP_OVS16   == (oversample)) ? UART_G_CTRL_OVS_IRDA_LP_OVS16 : \
         ((UART_G_UART_IRDA_LP_OVS32   == (oversample)) ? UART_G_CTRL_OVS_IRDA_LP_OVS32 : \
          ((UART_G_UART_IRDA_LP_OVS48   == (oversample)) ? UART_G_CTRL_OVS_IRDA_LP_OVS48 : \
           ((UART_G_UART_IRDA_LP_OVS96   == (oversample)) ? UART_G_CTRL_OVS_IRDA_LP_OVS96 : \
            ((UART_G_UART_IRDA_LP_OVS192  == (oversample)) ? UART_G_CTRL_OVS_IRDA_LP_OVS192 : \
             ((UART_G_UART_IRDA_LP_OVS768  == (oversample)) ? UART_G_CTRL_OVS_IRDA_LP_OVS768 : \
              ((UART_G_UART_IRDA_LP_OVS1536 == (oversample)) ? UART_G_CTRL_OVS_IRDA_LP_OVS1536 : \
                                                                          UART_G_CTRL_OVS_IRDA_LP_OVS16)))))))

#define UART_G_GET_UART_RX_CTRL_ENABLED(direction) ((0u != (UART_G_UART_RX & (direction))) ? \
                                                                    (UART_G_RX_CTRL_ENABLED) : (0u))

#define UART_G_GET_UART_TX_CTRL_ENABLED(direction) ((0u != (UART_G_UART_TX & (direction))) ? \
                                                                    (UART_G_TX_CTRL_ENABLED) : (0u))


/***************************************
*        SPI Register Settings
***************************************/

#define UART_G_CTRL_SPI      (UART_G_CTRL_MODE_SPI)
#define UART_G_SPI_RX_CTRL   (UART_G_RX_CTRL_ENABLED)
#define UART_G_SPI_TX_CTRL   (UART_G_TX_CTRL_ENABLED)


/***************************************
*       SPI Init Register Settings
***************************************/

#if(UART_G_SCB_MODE_SPI_CONST_CFG)

    /* SPI Configuration */
    #define UART_G_SPI_DEFAULT_CTRL \
                    (UART_G_GET_CTRL_OVS(UART_G_SPI_OVS_FACTOR)         | \
                     UART_G_GET_CTRL_EC_AM_MODE(UART_G_SPI_WAKE_ENABLE) | \
                     UART_G_CTRL_SPI)

    #define UART_G_SPI_DEFAULT_SPI_CTRL \
                    (UART_G_GET_SPI_CTRL_CONTINUOUS    (UART_G_SPI_TRANSFER_SEPARATION)       | \
                     UART_G_GET_SPI_CTRL_SELECT_PRECEDE(UART_G_SPI_SUB_MODE &                   \
                                                                  UART_G_SPI_MODE_TI_PRECEDES_MASK)     | \
                     UART_G_GET_SPI_CTRL_SCLK_MODE     (UART_G_SPI_CLOCK_MODE)                | \
                     UART_G_GET_SPI_CTRL_LATE_MISO_SAMPLE(UART_G_SPI_LATE_MISO_SAMPLE_ENABLE) | \
                     UART_G_GET_SPI_CTRL_SUB_MODE      (UART_G_SPI_SUB_MODE)                  | \
                     UART_G_GET_SPI_CTRL_MASTER_MODE   (UART_G_SPI_MODE))

    /* RX direction */
    #define UART_G_SPI_DEFAULT_RX_CTRL \
                    (UART_G_GET_RX_CTRL_DATA_WIDTH(UART_G_SPI_RX_DATA_BITS_NUM)     | \
                     UART_G_GET_RX_CTRL_BIT_ORDER (UART_G_SPI_BITS_ORDER)           | \
                     UART_G_GET_RX_CTRL_MEDIAN    (UART_G_SPI_MEDIAN_FILTER_ENABLE) | \
                     UART_G_SPI_RX_CTRL)

    #define UART_G_SPI_DEFAULT_RX_FIFO_CTRL \
                    UART_G_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(UART_G_SPI_RX_TRIGGER_LEVEL)

    /* TX direction */
    #define UART_G_SPI_DEFAULT_TX_CTRL \
                    (UART_G_GET_TX_CTRL_DATA_WIDTH(UART_G_SPI_TX_DATA_BITS_NUM) | \
                     UART_G_GET_TX_CTRL_BIT_ORDER (UART_G_SPI_BITS_ORDER)       | \
                     UART_G_SPI_TX_CTRL)

    #define UART_G_SPI_DEFAULT_TX_FIFO_CTRL \
                    UART_G_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(UART_G_SPI_TX_TRIGGER_LEVEL)

    /* Interrupt sources */
    #define UART_G_SPI_DEFAULT_INTR_SPI_EC_MASK   (UART_G_NO_INTR_SOURCES)

    #define UART_G_SPI_DEFAULT_INTR_I2C_EC_MASK   (UART_G_NO_INTR_SOURCES)
    #define UART_G_SPI_DEFAULT_INTR_SLAVE_MASK \
                    (UART_G_SPI_INTR_RX_MASK & UART_G_INTR_SLAVE_SPI_BUS_ERROR)

    #define UART_G_SPI_DEFAULT_INTR_MASTER_MASK \
                    (UART_G_SPI_INTR_TX_MASK & UART_G_INTR_MASTER_SPI_DONE)

    #define UART_G_SPI_DEFAULT_INTR_RX_MASK \
                    (UART_G_SPI_INTR_RX_MASK & (uint32) ~UART_G_INTR_SLAVE_SPI_BUS_ERROR)

    #define UART_G_SPI_DEFAULT_INTR_TX_MASK \
                    (UART_G_SPI_INTR_TX_MASK & (uint32) ~UART_G_INTR_MASTER_SPI_DONE)

#endif /* (UART_G_SCB_MODE_SPI_CONST_CFG) */


/***************************************
*        UART Register Settings
***************************************/

#define UART_G_CTRL_UART      (UART_G_CTRL_MODE_UART)
#define UART_G_UART_RX_CTRL   (UART_G_RX_CTRL_LSB_FIRST) /* LSB for UART goes first */
#define UART_G_UART_TX_CTRL   (UART_G_TX_CTRL_LSB_FIRST) /* LSB for UART goes first */


/***************************************
*      UART Init Register Settings
***************************************/

#if(UART_G_SCB_MODE_UART_CONST_CFG)

    /* UART configuration */
    #if(UART_G_UART_MODE_IRDA == UART_G_UART_SUB_MODE)

        #define UART_G_DEFAULT_CTRL_OVS   ((0u != UART_G_UART_IRDA_LOW_POWER) ?              \
                                (UART_G_UART_GET_CTRL_OVS_IRDA_LP(UART_G_UART_OVS_FACTOR)) : \
                                (UART_G_CTRL_OVS_IRDA_OVS16))

    #else

        #define UART_G_DEFAULT_CTRL_OVS   UART_G_GET_CTRL_OVS(UART_G_UART_OVS_FACTOR)

    #endif /* (UART_G_UART_MODE_IRDA == UART_G_UART_SUB_MODE) */

    #define UART_G_UART_DEFAULT_CTRL \
                                (UART_G_GET_CTRL_ADDR_ACCEPT(UART_G_UART_MP_ACCEPT_ADDRESS) | \
                                 UART_G_DEFAULT_CTRL_OVS                                              | \
                                 UART_G_CTRL_UART)

    #define UART_G_UART_DEFAULT_UART_CTRL \
                                    (UART_G_GET_UART_CTRL_MODE(UART_G_UART_SUB_MODE))

    /* RX direction */
    #define UART_G_UART_DEFAULT_RX_CTRL_PARITY \
                                ((UART_G_UART_PARITY_NONE != UART_G_UART_PARITY_TYPE) ?      \
                                  (UART_G_GET_UART_RX_CTRL_PARITY(UART_G_UART_PARITY_TYPE) | \
                                   UART_G_UART_RX_CTRL_PARITY_ENABLED) : (0u))

    #define UART_G_UART_DEFAULT_UART_RX_CTRL \
                    (UART_G_GET_UART_RX_CTRL_MODE(UART_G_UART_STOP_BITS_NUM)                    | \
                     UART_G_GET_UART_RX_CTRL_POLARITY(UART_G_UART_IRDA_POLARITY)                | \
                     UART_G_GET_UART_RX_CTRL_MP_MODE(UART_G_UART_MP_MODE_ENABLE)                | \
                     UART_G_GET_UART_RX_CTRL_DROP_ON_PARITY_ERR(UART_G_UART_DROP_ON_PARITY_ERR) | \
                     UART_G_GET_UART_RX_CTRL_DROP_ON_FRAME_ERR(UART_G_UART_DROP_ON_FRAME_ERR)   | \
                     UART_G_UART_DEFAULT_RX_CTRL_PARITY)

    #define UART_G_UART_DEFAULT_RX_CTRL \
                                (UART_G_GET_RX_CTRL_DATA_WIDTH(UART_G_UART_DATA_BITS_NUM)        | \
                                 UART_G_GET_RX_CTRL_MEDIAN    (UART_G_UART_MEDIAN_FILTER_ENABLE) | \
                                 UART_G_GET_UART_RX_CTRL_ENABLED(UART_G_UART_DIRECTION))

    #define UART_G_UART_DEFAULT_RX_FIFO_CTRL \
                                UART_G_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(UART_G_UART_RX_TRIGGER_LEVEL)

    #define UART_G_UART_DEFAULT_RX_MATCH_REG  ((0u != UART_G_UART_MP_MODE_ENABLE) ?          \
                                (UART_G_GET_RX_MATCH_ADDR(UART_G_UART_MP_RX_ADDRESS) | \
                                 UART_G_GET_RX_MATCH_MASK(UART_G_UART_MP_RX_ADDRESS_MASK)) : (0u))

    /* TX direction */
    #define UART_G_UART_DEFAULT_TX_CTRL_PARITY (UART_G_UART_DEFAULT_RX_CTRL_PARITY)

    #define UART_G_UART_DEFAULT_UART_TX_CTRL \
                                (UART_G_GET_UART_TX_CTRL_MODE(UART_G_UART_STOP_BITS_NUM)       | \
                                 UART_G_GET_UART_TX_CTRL_RETRY_NACK(UART_G_UART_RETRY_ON_NACK) | \
                                 UART_G_UART_DEFAULT_TX_CTRL_PARITY)

    #define UART_G_UART_DEFAULT_TX_CTRL \
                                (UART_G_GET_TX_CTRL_DATA_WIDTH(UART_G_UART_DATA_BITS_NUM) | \
                                 UART_G_GET_UART_TX_CTRL_ENABLED(UART_G_UART_DIRECTION))

    #define UART_G_UART_DEFAULT_TX_FIFO_CTRL \
                                UART_G_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(UART_G_UART_TX_TRIGGER_LEVEL)

    /* Interrupt sources */
    #define UART_G_UART_DEFAULT_INTR_I2C_EC_MASK  (UART_G_NO_INTR_SOURCES)
    #define UART_G_UART_DEFAULT_INTR_SPI_EC_MASK  (UART_G_NO_INTR_SOURCES)
    #define UART_G_UART_DEFAULT_INTR_SLAVE_MASK   (UART_G_NO_INTR_SOURCES)
    #define UART_G_UART_DEFAULT_INTR_MASTER_MASK  (UART_G_NO_INTR_SOURCES)
    #define UART_G_UART_DEFAULT_INTR_RX_MASK      (UART_G_UART_INTR_RX_MASK)
    #define UART_G_UART_DEFAULT_INTR_TX_MASK      (UART_G_UART_INTR_TX_MASK)

#endif /* (UART_G_SCB_MODE_UART_CONST_CFG) */

#endif /* CY_SCB_SPI_UART_UART_G_H */


/* [] END OF FILE */
