/******************************************************************************
* Project Name		: GPS Shield
* File Name			: main.c
* Version 			: 1.0
* Device Used		: CY8C4245AXI-483
* Software Used		: PSoC Creator 2.2 SP1
* Compiler    		: ARMGCC 4.4.1, ARM RVDS Generic , ARM MDK Generic
* Related Hardware	: CY8CKIT-042 PSoC 4 Pioneer Kit 
*
********************************************************************************
* Copyright (2013), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/

/******************************************************************************
*                           THEORY OF OPERATION
* This project demonstrates the GPS application using Arduino GPS shield and PSOC4.
* After Receive GPS data.PSOC4 will pick up the expected information on LCD.
* Hardware connection on the Kit
*for more details see heng#3
******************************************************************************/ 
#include <device.h>
#include <stdio.h>

#define GO_LATITUDE     1u
#define GO_LONGITUDE    2u
#define TIME            3u

void GetGPSMessage(uint8 State);

char dataByte = 0x00; //GPS data

char rxBuf[1024];
char *rxBufPtr = rxBuf;

char time[10];      //time
char *timePtr = time;

uint8 commaNum=0;   //comma for regular
char fixFlag='0';

char latitude[9];   //latitude
char *latitudePtr = latitude;

char longitude[10]; //longitude        
char *longitudePtr = longitude;

//char dirLa='0'; //record north or south;
//char dirLo='0'; //record west or east;

uint8 commaLoc[14]={0};

char colon = ':';
uint8 colon_flag = 0;

uint8 end_flag = 0;
//uint8 State=GO_LATITUDE;
uint8 State=GO_LATITUDE;

int main()
{
    
    
	CyGlobalIntEnable;
    isr_Start();
    
	LCD_Start();
    /* LCD  Initializtion */
	LCD_Position(0, 0);
    LCD_PrintString("GPS Shield");
    /* GPS UART Initializtion */
	UART_G_Start();
    /* Debug UART Initializtion */
	UART_DBG_Start();	
	UART_DBG_UartPutString("GPS Shield\r\n");
    
    Clock_Start();
    
    
	for(;;)
   	 {
        /* When the GPS shield,you can simulate by sending data through Debug UART */
	//	dataByte = UART_DBG_UartGetChar();
    	dataByte = UART_G_GetChar();
  
		if (dataByte == 0x24)
		{
			for(;;)
			{
				switch (dataByte)
				{
					case 0x00:
					{
						break;
					}
					
					case 0x24: //Begin with '$'
					{
						*rxBufPtr = dataByte;
						rxBufPtr++;
				//		UART_DBG_UartPutChar(dataByte);
						break;
					}
					
					case 0x0A: //End with '<LF>'
					{
						*rxBufPtr = dataByte;
						*(rxBufPtr + 1) = 0x00;
						end_flag = 1;
				//		UART_DBG_UartPutChar(dataByte);
						break;
					}
					
					default:
					{
						*rxBufPtr = dataByte;
						rxBufPtr++;
				//		UART_DBG_UartPutChar(dataByte);
						break;
					}
				}
				
				
				
			//   	  dataByte = UART_DBG_UartGetChar();
                dataByte = UART_G_GetChar();
				
				if (end_flag == 1)
				{
					end_flag = 0;
					rxBufPtr = rxBuf;
				
                 
					if ( *(rxBufPtr + 4) == 'G' ) //$GPGGA Frame
					{   
                     	commaNum=0;
                        uint8 i=0;
						for(i=0;i<100;i++)//get comma location and fixFlag value
						{
							if(*(rxBuf+i)==',')
							{	
								*(commaLoc+commaNum)=i; //get the comma location
								commaNum++;											      
								if(commaNum == 6)
								{
									fixFlag=*(rxBuf+i+1); //get fixFlag
								}
                                
							}
								
						}
                         	
						if((fixFlag == '1')||(fixFlag == '2'))
						{	
                        	GetGPSMessage(State);
                            if(State == TIME+1)    
                            {State = GO_LATITUDE;}
                            
							     
						}
                      
                     
					}
					
				}
                
			}
		}
    }
}

void GetGPSMessage(uint8 State)
{
        uint8 latloc=0;
		uint8 loloc=0;
        
        switch( State )
        {
        case GO_LATITUDE: 
            
            memset(latitude,0,9);  //clear memory
									
            uint8 la=0;
			for(la=(*(commaLoc+1)+1);la<*(commaLoc+2);la++) //get Latitude
				{
					*(latitudePtr+latloc) = *(rxBufPtr+la);
					latloc++;
				}
			LCD_ClearDisplay();
            LCD_Position(0, 0);
           LCD_PrintString( "latitude is:");
        LCD_Position(1, 0);
		LCD_PrintString(latitude);
							
			memset(latitude,0,9);  //clear memory
            
          //  UART_DBG_UartPutChar(State);
            
            break;
            
        case GO_LONGITUDE :
            
            memset(longitude,0,10);  //clear memory
            uint8 lo=0;
			for(lo=(*(commaLoc+3)+1);lo<*(commaLoc+4);lo++)	//get Longtitude
				{
				*(longitudePtr+loloc) = *(rxBufPtr+lo);
				loloc++;
				}
				
          LCD_ClearDisplay();
          LCD_Position(0, 0);
          LCD_PrintString( "longitude is:");
        LCD_Position(1, 0);
		LCD_PrintString(longitude);
			memset(longitude,0,10);  //clear memory
           UART_DBG_UartPutChar(State);
            break;
            
        case TIME:
            
             colon_flag = ~colon_flag;
					
			if (colon_flag == 0x00) //get time
			    {
				 colon = ' ';
				}
			else
				{
				colon = ':';
				}
				*timePtr = *(rxBufPtr + 7);
				*(timePtr + 1) = *(rxBufPtr + 8);
				*(timePtr + 2) = colon;
												
				*(timePtr + 3) = *(rxBufPtr + 9);
				*(timePtr + 4) = *(rxBufPtr + 10);
				*(timePtr + 5) = colon;
						
				*(timePtr + 6) = *(rxBufPtr + 11);
				*(timePtr + 7) = *(rxBufPtr + 12);
                LCD_Position(0, 0);
		       LCD_PrintString("Time is:       ");
            LCD_Position(1, 0);
			LCD_PrintString(time);
                memset(time,0,10); 
				timePtr = time;
                
             //   UART_DBG_UartPutChar(State);
                break;
            default:
                break;
        
        }

						
                       
}                                   
/* [] END OF FILE */
